@@ -25,6 +25,7 @@ import (
 	"fmt"
 	"io"
 	"os"
+	"strings"
 
 	"github.com/pkg/errors"
 	"github.com/shenwei356/bio/taxdump"
@@ -36,10 +37,10 @@ import (
 
 var commonCmd = &cobra.Command{
 	Use:   "common",
-	Short: "Find k-mers shared by most of multiple binary files",
-	Long: `Find k-mers shared by most of multiple binary files
+	Short: "Find k-mers shared by most of the binary files",
+	Long: `Find k-mers shared by most of the binary files
 
-This command is similar to "unikmer inter" but with looser restriction,
+This command is similar to "unikmer inter" but with a looser restriction,
 k-mers shared by some number/proportion of multiple files are outputted.
 
 Attentions:
@@ -127,7 +128,7 @@ Tips:
 			checkError(err)
 			defer r.Close()
 
-			if !isStdout(outFile) {
+			if !isStdout(outFile) && !strings.HasSuffix(outFile, extDataFile) {
 				outFile += extDataFile
 			}
 			outfh, gw, w, err := outStream(outFile, opt.Compress, opt.CompressionLevel)
@@ -296,7 +297,7 @@ Tips:
 			log.Infof("exporting k-mers")
 		}
 
-		if !isStdout(outFile) {
+		if !isStdout(outFile) && !strings.HasSuffix(outFile, extDataFile) {
 			outFile += extDataFile
 		}
 		outfh, gw, w, err := outStream(outFile, opt.Compress, opt.CompressionLevel)
