@@ -25,6 +25,7 @@ import (
 	"fmt"
 	"io"
 	"os"
+	"strings"
 	"sync"
 
 	"github.com/pkg/errors"
@@ -37,8 +38,8 @@ import (
 
 var diffCmd = &cobra.Command{
 	Use:   "diff",
-	Short: "Set difference of multiple binary files",
-	Long: `Set difference of multiple binary files
+	Short: "Set difference of k-mers in multiple binary files",
+	Long: `Set difference of k-mers in multiple binary files
 
 Attentions:
   0. The first file should be sorted.
@@ -156,7 +157,7 @@ Tips:
 				log.Infof("exporting k-mers")
 			}
 
-			if !isStdout(outFile) {
+			if !isStdout(outFile) && !strings.HasSuffix(outFile, extDataFile) {
 				outFile += extDataFile
 			}
 			outfh, gw, w, err := outStream(outFile, opt.Compress, opt.CompressionLevel)
@@ -529,7 +530,7 @@ Tips:
 			log.Infof("exporting k-mers")
 		}
 
-		if !isStdout(outFile) {
+		if !isStdout(outFile) && !strings.HasSuffix(outFile, extDataFile) {
 			outFile += extDataFile
 		}
 		outfh, gw, w, err := outStream(outFile, opt.Compress, opt.CompressionLevel)
