@@ -25,6 +25,7 @@ import (
 	"fmt"
 	"io"
 	"os"
+	"strings"
 
 	"github.com/pkg/errors"
 	"github.com/shenwei356/unik/v5"
@@ -70,7 +71,7 @@ Attentions:
 		penaltyS := getFlagInt(cmd, "penalty-s")
 		penaltyD := getFlagInt(cmd, "penalty-d")
 
-		if !isStdout(outFile) {
+		if !isStdout(outFile) && !strings.HasSuffix(outFile, extDataFile) {
 			outFile += extDataFile
 		}
 		outfh, gw, w, err := outStream(outFile, opt.Compress, opt.CompressionLevel)
