@@ -25,6 +25,7 @@ import (
 	"fmt"
 	"io"
 	"os"
+	"strings"
 
 	"github.com/pkg/errors"
 	"github.com/shenwei356/bio/taxdump"
@@ -35,8 +36,8 @@ import (
 
 var interCmd = &cobra.Command{
 	Use:   "inter",
-	Short: "Intersection of multiple binary files",
-	Long: `Intersection of multiple binary files
+	Short: "Intersection of k-mers in multiple binary files",
+	Long: `Intersection of k-mers in multiple binary files
 
 Attentions:
   0. All input files should be sorted, and output file is sorted.
@@ -100,7 +101,7 @@ Tips:
 			checkError(err)
 			defer r.Close()
 
-			if !isStdout(outFile) {
+			if !isStdout(outFile) && !strings.HasSuffix(outFile, extDataFile) {
 				outFile += extDataFile
 			}
 			outfh, gw, w, err := outStream(outFile, opt.Compress, opt.CompressionLevel)
@@ -307,7 +308,7 @@ Tips:
 			log.Infof("exporting k-mers")
 		}
 
-		if !isStdout(outFile) {
+		if !isStdout(outFile) && !strings.HasSuffix(outFile, extDataFile) {
 			outFile += extDataFile
 		}
 		outfh, gw, w, err := outStream(outFile, opt.Compress, opt.CompressionLevel)
