@@ -208,7 +208,7 @@ Attention:
 					seqClone = append(seqClone, seqClone[0:k-1]...)
 				}
 				sequences = append(sequences, seqClone)
-				ids = append(ids, record.ID)
+				ids = append(ids, []byte(string(record.ID)))
 
 				for {
 					code, ok, err = iter.Next()
@@ -280,6 +280,8 @@ Attention:
 							outfh.WriteString(fmt.Sprintf("%s\t%d\t%d\t%s\t0\t.\n",
 								ids[i], j, j+k, kmer))
 						}
+
+						delete(m, code)
 					}
 				}
 			}()
