@@ -27,6 +27,7 @@ import (
 	"os"
 	"path/filepath"
 	"runtime"
+	"strings"
 	"sync"
 
 	"github.com/pkg/errors"
@@ -41,8 +42,8 @@ import (
 
 var sortCmd = &cobra.Command{
 	Use:   "sort",
-	Short: "Sort k-mers in binary files to reduce file size",
-	Long: `Sort k-mers in binary files to reduce file size
+	Short: "Sort k-mers to reduce the file size and accelerate downstream analysis",
+	Long: `Sort k-mers to reduce the file size and accelerate downstream analysis
 
 Attentions:
   1. The 'canonical/scaled/hashed' flags of all files should be consistent.
@@ -107,7 +108,7 @@ Tips:
 		var mt []CodeTaxid
 
 		outFile := outFile0
-		if !isStdout(outFile) {
+		if !isStdout(outFile) && !strings.HasSuffix(outFile, extDataFile) {
 			outFile += extDataFile
 		}
 
